@@ -54,6 +54,10 @@ using namespace SPIRV;
 using namespace llvm;
 using namespace spv;
 
+namespace SPIRV {
+class BuiltinCallMutator;
+} // namespace SPIRV
+
 namespace OCLUtil {
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -94,11 +98,19 @@ enum OCLScopeKind {
 // To avoid any inconsistence here, constants are explicitly initialized with
 // the corresponding constants from 'std::memory_order' enum.
 enum OCLMemOrderKind {
+#if __cplusplus >= 202002L
+  OCLMO_relaxed = std::memory_order_relaxed,
+  OCLMO_acquire = std::memory_order_acquire,
+  OCLMO_release = std::memory_order_release,
+  OCLMO_acq_rel = std::memory_order_acq_rel,
+  OCLMO_seq_cst = std::memory_order_seq_cst
+#else
   OCLMO_relaxed = std::memory_order::memory_order_relaxed,
   OCLMO_acquire = std::memory_order::memory_order_acquire,
   OCLMO_release = std::memory_order::memory_order_release,
   OCLMO_acq_rel = std::memory_order::memory_order_acq_rel,
   OCLMO_seq_cst = std::memory_order::memory_order_seq_cst
+#endif
 };
 
 enum IntelFPGAMemoryAccessesVal {
@@ -123,6 +135,8 @@ typedef SPIRVMap<OCLMemOrderKind, unsigned, MemorySemanticsMask> OCLMemOrderMap;
 
 typedef SPIRVMap<OCLScopeKind, Scope> OCLMemScopeMap;
 
+typedef SPIRVMap<std::string, Scope> OCLStrMemScopeMap;
+
 typedef SPIRVMap<std::string, SPIRVGroupOperationKind>
     SPIRSPIRVGroupOperationMap;
 
@@ -154,12 +168,10 @@ struct OCLBuiltinTransInfo {
   std::string MangledName;
   std::string Postfix; // Postfix to be added
   /// Postprocessor of operands
-  std::function<void(std::vector<Value *> &)> PostProc;
-  Type *RetTy;      // Return type of the translated function
-  bool IsRetSigned; // When RetTy is int, determines if extensions
-                    // on it should be a sext or zet.
-  OCLBuiltinTransInfo() : RetTy(nullptr), IsRetSigned(false) {
-    PostProc = [](std::vector<Value *> &) {};
+  std::function<void(BuiltinCallMutator &)> PostProc;
+  Type *RetTy; // Return type of the translated function
+  OCLBuiltinTransInfo() : RetTy(nullptr) {
+    PostProc = [](BuiltinCallMutator &) {};
   }
 };
 
@@ -231,8 +243,12 @@ const static char AtomicInit[] = "atomic_init";
 const static char AtomicWorkItemFence[] = "atomic_work_item_fence";
 const static char Barrier[] = "barrier";
 const static char Clamp[] = "clamp";
+const static char ClockReadPrefix[] = "clock_read_";
 const static char ConvertPrefix[] = "convert_";
 const static char Dot[] = "dot";
+const static char DotAccSat[] = "dot_acc_sat";
+const static char Dot4x8PackedPrefix[] = "dot_4x8packed_";
+const static char DotAccSat4x8PackedPrefix[] = "dot_acc_sat_4x8packed_";
 const static char EnqueueKernel[] = "enqueue_kernel";
 const static char FixedSqrtINTEL[] = "intel_arbitrary_fixed_sqrt";
 const static char FixedRecipINTEL[] = "intel_arbitrary_fixed_recip";
@@ -304,6 +320,28 @@ const static char SubgroupBlockWriteINTELPrefix[] =
     "intel_sub_group_block_write";
 const static char SubgroupImageMediaBlockINTELPrefix[] =
     "intel_sub_group_media_block";
+const static char SplitBarrierINTELPrefix[] = "intel_work_group_barrier_";
+const static char LDEXP[] = "ldexp";
+#define _SPIRV_OP(x)                                                           \
+  const static char ConvertBFloat16##x##AsUShort##x[] =                        \
+      "intel_convert_bfloat16" #x "_as_ushort" #x;
+_SPIRV_OP()
+_SPIRV_OP(2)
+_SPIRV_OP(3)
+_SPIRV_OP(4)
+_SPIRV_OP(8)
+_SPIRV_OP(16)
+#undef _SPIRV_OP
+#define _SPIRV_OP(x)                                                           \
+  const static char ConvertAsBFloat16##x##Float##x[] =                         \
+      "intel_convert_as_bfloat16" #x "_float" #x;
+_SPIRV_OP()
+_SPIRV_OP(2)
+_SPIRV_OP(3)
+_SPIRV_OP(4)
+_SPIRV_OP(8)
+_SPIRV_OP(16)
+#undef _SPIRV_OP
 } // namespace kOCLBuiltinName
 
 /// Offset for OpenCL image channel order enumeration values.
@@ -321,8 +359,9 @@ const OCLScopeKind OCLLegacyAtomicMemScope = OCLMS_work_group;
 namespace kOCLVer {
 const unsigned CL12 = 102000;
 const unsigned CL20 = 200000;
-const unsigned CL21 = 201000;
 const unsigned CL30 = 300000;
+const unsigned CLCXX10 = 100000;
+const unsigned CLCXX2021 = 202100000;
 } // namespace kOCLVer
 
 namespace OclExt {
@@ -415,18 +454,19 @@ std::tuple<unsigned short, unsigned char, unsigned char>
 decodeOCLVer(unsigned Ver);
 
 /// Decode a MDNode assuming it contains three integer constants.
-void decodeMDNode(MDNode *N, unsigned &X, unsigned &Y, unsigned &Z);
+SmallVector<unsigned, 3> decodeMDNode(MDNode *N);
 
 /// Get full path from debug info metadata
 /// Return empty string if the path is not available.
 template <typename T> std::string getFullPath(const T *Scope) {
   if (!Scope)
     return std::string();
-  std::string Filename = Scope->getFilename().str();
-  if (sys::path::is_absolute(Filename))
-    return Filename;
+  StringRef Filename = Scope->getFilename();
+  auto Style = sys::path::Style::native;
+  if (sys::path::is_absolute(Filename, Style))
+    return Filename.str();
   SmallString<16> DirName = Scope->getDirectory();
-  sys::path::append(DirName, sys::path::Style::posix, Filename);
+  sys::path::append(DirName, Style, Filename.str());
   return DirName.str().str();
 }
 
@@ -460,30 +500,6 @@ inline OCLMemOrderKind mapSPIRVMemOrderToOCL(unsigned Sema) {
   return OCLMemOrderMap::rmap(extractSPIRVMemOrderSemantic(Sema));
 }
 
-/// Mutate call instruction to call OpenCL builtin function.
-CallInst *mutateCallInstOCL(
-    Module *M, CallInst *CI,
-    std::function<std::string(CallInst *, std::vector<Value *> &)> ArgMutate,
-    AttributeList *Attrs = nullptr);
-
-/// Mutate call instruction to call OpenCL builtin function.
-Instruction *mutateCallInstOCL(
-    Module *M, CallInst *CI,
-    std::function<std::string(CallInst *, std::vector<Value *> &, Type *&RetTy)>
-        ArgMutate,
-    std::function<Instruction *(CallInst *)> RetMutate,
-    AttributeList *Attrs = nullptr, bool TakeFuncName = false);
-
-/// Check if instruction is bitcast from spirv.ConstantSampler to spirv.Sampler
-bool isSamplerInitializer(Instruction *Inst);
-
-/// Check if instruction is bitcast from spirv.ConstantPipeStorage
-/// to spirv.PipeStorage
-bool isPipeStorageInitializer(Instruction *Inst);
-
-/// Check (isSamplerInitializer || isPipeStorageInitializer)
-bool isSpecialTypeInitializer(Instruction *Inst);
-
 bool isPipeOrAddressSpaceCastBI(const StringRef MangledName);
 bool isEnqueueKernelBI(const StringRef MangledName);
 bool isKernelQueryBI(const StringRef MangledName);
@@ -494,14 +510,6 @@ bool isSamplerTy(Type *Ty);
 // Checks if the binary operator is an unfused fmul + fadd instruction.
 bool isUnfusedMulAdd(BinaryOperator *B);
 
-template <typename T> std::string toString(const T *Object) {
-  std::string S;
-  llvm::raw_string_ostream RSOS(S);
-  Object->print(RSOS);
-  RSOS.flush();
-  return S;
-}
-
 // Get data and vector size postfix for sugroup_block_{read|write} builtins
 // as specified by cl_intel_subgroups* extensions.
 // Scalar data assumed to be represented as vector of one element.
@@ -510,6 +518,8 @@ std::string getIntelSubgroupBlockDataPostfix(unsigned ElementBitSize,
 
 void insertImageNameAccessQualifier(SPIRVAccessQualifierKind Acc,
                                     std::string &Name);
+
+std::unique_ptr<SPIRV::BuiltinFuncMangleInfo> makeMangler(Function &F);
 } // namespace OCLUtil
 
 using namespace OCLUtil;
@@ -519,7 +529,7 @@ template <class KeyTy, class ValTy, class Identifier = void>
 Instruction *
 getOrCreateSwitchFunc(StringRef MapName, Value *V,
                       const SPIRVMap<KeyTy, ValTy, Identifier> &Map,
-                      bool IsReverse, Optional<int> DefaultCase,
+                      bool IsReverse, std::optional<int> DefaultCase,
                       Instruction *InsertPoint, int KeyMask = 0) {
   static_assert(std::is_convertible<KeyTy, int>::value &&
                     std::is_convertible<ValTy, int>::value,
@@ -534,17 +544,18 @@ getOrCreateSwitchFunc(StringRef MapName, Value *V,
   F->setLinkage(GlobalValue::PrivateLinkage);
 
   LLVMContext &Ctx = M->getContext();
-  BasicBlock *BB = BasicBlock::Create(Ctx, "entry", F);
-  IRBuilder<> IRB(BB);
+  BasicBlock *EntryBB = BasicBlock::Create(Ctx, "entry", F);
+  IRBuilder<> EntryIRB(EntryBB);
+  AllocaInst *Result = EntryIRB.CreateAlloca(Ty, nullptr, "result");
   SwitchInst *SI;
   F->arg_begin()->setName("key");
   if (KeyMask) {
     Value *MaskV = ConstantInt::get(Type::getInt32Ty(Ctx), KeyMask);
-    Value *NewKey = IRB.CreateAnd(MaskV, F->arg_begin());
+    Value *NewKey = EntryIRB.CreateAnd(MaskV, F->arg_begin());
     NewKey->setName("key.masked");
-    SI = IRB.CreateSwitch(NewKey, BB);
+    SI = EntryIRB.CreateSwitch(NewKey, EntryBB);
   } else {
-    SI = IRB.CreateSwitch(F->arg_begin(), BB);
+    SI = EntryIRB.CreateSwitch(F->arg_begin(), EntryBB);
   }
 
   if (!DefaultCase) {
@@ -554,20 +565,54 @@ getOrCreateSwitchFunc(StringRef MapName, Value *V,
     SI->setDefaultDest(DefaultBB);
   }
 
+  BasicBlock *ExitBB = BasicBlock::Create(Ctx, "exit", F);
+  BasicBlock *CaseBB = nullptr;
   Map.foreach ([&](int Key, int Val) {
     if (IsReverse)
       std::swap(Key, Val);
-    BasicBlock *CaseBB = BasicBlock::Create(Ctx, "case." + Twine(Key), F);
+    CaseBB = BasicBlock::Create(Ctx, "case." + Twine(Key), F);
     IRBuilder<> CaseIRB(CaseBB);
-    CaseIRB.CreateRet(CaseIRB.getInt32(Val));
-    SI->addCase(IRB.getInt32(Key), CaseBB);
+    CaseIRB.CreateStore(CaseIRB.getInt32(Val), Result);
+    CaseIRB.CreateBr(ExitBB);
+    SI->addCase(EntryIRB.getInt32(Key), CaseBB);
     if (Key == DefaultCase)
       SI->setDefaultDest(CaseBB);
   });
-  assert(SI->getDefaultDest() != BB && "Invalid default destination in switch");
+
+  ExitBB->moveAfter(CaseBB);
+  IRBuilder<> ExitIRB(ExitBB);
+  LoadInst *RetVal = ExitIRB.CreateLoad(Ty, Result, "retVal");
+  ExitIRB.CreateRet(RetVal);
+
+  assert(SI->getDefaultDest() != EntryBB &&
+         "Invalid default destination in switch");
   return addCallInst(M, MapName, Ty, V, nullptr, InsertPoint);
 }
 
+/// Maps LLVM SyncScope into SPIR-V Scope.
+///
+/// \param [in] Ctx Context for the LLVM SyncScope
+/// \param [in] Id SyncScope::ID value which needs to be mapped to SPIR-V Scope
+inline spv::Scope toSPIRVScope(const LLVMContext &Ctx, SyncScope::ID Id) {
+  // We follow Clang/LLVM convention by which the default is System scope, which
+  // in SPIR-V maps to CrossDevice scope. This is in order to ensure that the
+  // resulting SPIR-V is conservatively correct (i.e. always works), under the
+  // assumption that it is the responsibility of the higher level language to
+  // choose a narrower scope, if desired.
+  switch (Id) {
+  case SyncScope::SingleThread:
+    return spv::ScopeInvocation;
+  case SyncScope::System:
+    return spv::ScopeCrossDevice;
+  default:
+    SmallVector<StringRef> SSIDs;
+    Ctx.getSyncScopeNames(SSIDs);
+    spv::Scope S = ScopeCrossDevice; // Default to CrossDevice scope.
+    OCLStrMemScopeMap::find(SSIDs[Id].str(), &S);
+    return S;
+  }
+}
+
 /// Performs conversion from OpenCL memory_scope into SPIR-V Scope.
 ///
 /// Supports both constant and non-constant values. To handle the latter case,
@@ -582,7 +627,7 @@ getOrCreateSwitchFunc(StringRef MapName, Value *V,
 /// \returns \c Value corresponding to SPIR-V Scope equivalent to OpenCL
 ///          memory_scope passed in \arg MemScope
 Value *transOCLMemScopeIntoSPIRVScope(Value *MemScope,
-                                      Optional<int> DefaultCase,
+                                      std::optional<int> DefaultCase,
                                       Instruction *InsertBefore);
 
 /// Performs conversion from OpenCL memory_order into SPIR-V Memory Semantics.
@@ -599,7 +644,7 @@ Value *transOCLMemScopeIntoSPIRVScope(Value *MemScope,
 /// \returns \c Value corresponding to SPIR-V Memory Semantics equivalent to
 ///          OpenCL memory_order passed in \arg MemOrder
 Value *transOCLMemOrderIntoSPIRVMemorySemantics(Value *MemOrder,
-                                                Optional<int> DefaultCase,
+                                                std::optional<int> DefaultCase,
                                                 Instruction *InsertBefore);
 
 /// Performs conversion from SPIR-V Scope into OpenCL memory_scope.
